==> notify-1.0.6-sources.jar: de/hglabor/notify/mixins/server/MixinPlayerManager.java <==
package de.hglabor.notify.mixins.server;

import de.hglabor.notify.events.server.player.PlayerJoinEvent;
import de.hglabor.notify.events.server.player.PlayerRemoveEvent;
import de.hglabor.notify.events.server.player.PostPlayerJoinEvent;
import de.hglabor.notify.events.server.player.PrePlayerJoinEvent;
import me.obsilabor.alert.EventManager;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2535;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_3324;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Environment(EnvType.SERVER)
@Mixin(value = class_3324.class)
public class MixinPlayerManager {

    @Unique private class_3222 notify$tempPlayer = null;

    @Inject(method = "onPlayerConnect", at = @At("HEAD"))
    public void onPlayerConnectPre(class_2535 clientConnection, class_3222 player, CallbackInfo ci) {
        notify$tempPlayer = player;
        EventManager.callEvent(new PrePlayerJoinEvent(player));
    }

    @Inject(method = "onPlayerConnect", at = @At("TAIL"))
    public void onPlayerConnectPost(class_2535 clientConnection, class_3222 player, CallbackInfo ci) {
        if (player.method_14239()) return; // Don't call event if played got kicked
        EventManager.callEvent(new PostPlayerJoinEvent(player));
    }

    @Redirect(
        method = "onPlayerConnect",
        at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/server/PlayerManager;broadcast(Lnet/minecraft/text/Text;Z)V"
        )
    )
    private void onPlayerConnect(class_3324 instance, class_2561 message, boolean overlay) {
        var evt = EventManager.callEvent(new PlayerJoinEvent(notify$tempPlayer, message));
        notify$tempPlayer = null;
        if (evt.getJoinMessage() != null) instance.method_43514(evt.getJoinMessage(), overlay);
    }

    @Inject(method = "remove", at = @At("TAIL"))
    public void remove(class_3222 player, CallbackInfo ci) {
        EventManager.callEvent(new PlayerRemoveEvent(player));
    }
}

==> notify-1.3.0-sources.jar: de/hglabor/notify/mixins/server/MixinPlayerManager.java <==
package de.hglabor.notify.mixins.server;

import de.hglabor.notify.events.server.player.PlayerJoinEvent;
import de.hglabor.notify.events.server.player.PlayerRemoveEvent;
import de.hglabor.notify.events.server.player.PostPlayerJoinEvent;
import de.hglabor.notify.events.server.player.PrePlayerJoinEvent;
import me.obsilabor.alert.EventManager;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_2535;
import net.minecraft.class_2561;
import net.minecraft.class_3222;
import net.minecraft.class_3324;
import net.minecraft.class_8792;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Environment(EnvType.SERVER)
@Mixin(value = class_3324.class)
public class MixinPlayerManager {

    @Unique private class_3222 notify$tempPlayer = null;

    @Inject(method = "onPlayerConnect", at = @At("HEAD"))
    public void onPlayerConnectPre(class_2535 clientConnection, class_3222 player, class_8792 connectedClientData, CallbackInfo ci) {
        notify$tempPlayer = player;
        EventManager.callEvent(new PrePlayerJoinEvent(player));
    }

    @Inject(method = "onPlayerConnect", at = @At("TAIL"))
    public void onPlayerConnectPost(class_2535 clientConnection, class_3222 player, class_8792 connectedClientData, CallbackInfo ci) {
        if (player.method_14239()) return; // Don't call event if played got kicked
        EventManager.callEvent(new PostPlayerJoinEvent(player));
    }

    @Redirect(
        method = "onPlayerConnect",
        at = @At(
            value = "INVOKE",
            target = "Lnet/minecraft/server/PlayerManager;broadcast(Lnet/minecraft/text/Text;Z)V"
        )
    )
    private void onPlayerConnect(class_3324 instance, class_2561 message, boolean overlay) {
        var evt = EventManager.callEvent(new PlayerJoinEvent(notify$tempPlayer, message));
        notify$tempPlayer = null;
        if (evt.getJoinMessage() != null) instance.method_43514(evt.getJoinMessage(), overlay);
    }

    @Inject(method = "remove", at = @At("TAIL"))
    public void remove(class_3222 player, CallbackInfo ci) {
        EventManager.callEvent(new PlayerRemoveEvent(player));
    }
}
